@@ -120,6 +120,8 @@ def handle_mqtt_messages(client, userdata, msg: mqtt.MQTTMessage):
         if effect != 1:
             try:
                 brightness = float(payload)
+                if brightness > 255 or brightness<0: 
+                    return
                 if effect == 0:
                     led.fill_led_with_color(
                         r*brightness/255.0, g*brightness/255.0, b*brightness/255.0)
@@ -130,19 +132,16 @@ def handle_mqtt_messages(client, userdata, msg: mqtt.MQTTMessage):
         mqttclient.publish(MQTT_BASE_TOPIC+"/report/brightness", int(brightness))
     elif topic == MQTT_BASE_TOPIC+"/control/color":
         if effect != 1:
-            if effector != None:
-                effector.stop_effect()
-                effector = None
-                effect = 0
-                mqttclient.publish(MQTT_BASE_TOPIC+"/report/effect",
-                        led_effects.effects[effect]['name'])
             try:
                 [rtmp,gtmp,btmp] = payload.split(',')
                 r = float(rtmp)
                 g = float(gtmp)
                 b = float(btmp)
-                led.fill_led_with_color(
-                    r*brightness/255.0, g*brightness/255.0, b*brightness/255.0)
+                if r<0 or r>255 or g<0 or g>255 or b<0 or b>255:
+                    return
+                if effect == 0:
+                    led.fill_led_with_color(
+                        r*brightness/255.0, g*brightness/255.0, b*brightness/255.0)
             except ValueError:
                 print("Invalid Payload")
                 return
